@@ -42,13 +42,16 @@ NULL
 ##' @rdname catalog-extract
 ##' @export
 setMethod("[[", c("DatasetCatalog", "character"), function (x, i, ...) {
-    DatasetTuple(index_url=self(x), entity_url=i, body=index(x)[[i]])
+    w <- whichNameOrURL(x, i)
+    x[[w]]
 })
 ##' @rdname catalog-extract
 ##' @export
 setMethod("[[", c("DatasetCatalog", "ANY"), function (x, i, ...) {
+    b <- callNextMethod(x, i, ...)
+    if (is.null(b)) return(NULL)
     DatasetTuple(index_url=self(x), entity_url=urls(x)[i],
-        body=index(x)[[i]])
+        body=b)
 })
 
 ##' Get and set names, aliases on Catalog-type objects
@@ -58,7 +61,10 @@ setMethod("[[", c("DatasetCatalog", "ANY"), function (x, i, ...) {
 ##' variable. They work like the base R names methods.
 ##'
 ##' Note that the \code{names} method on a Dataset returns the aliases of its
-##' variables by default. See the vignette on variables for more information.
+##' variables by default. This is controlled by
+##' \code{getOption("crunch.namekey.dataset")}, which is "alias" by default.
+##' Set \code{options(crunch.namekey.dataset="name")} if you wish to use
+##' variable names. See the vignette on variables for more information.
 ##'
 ##' @param x a VariableCatalog, Subvariables, or similar object
 ##' @param value For the setters, an appropriate-length character vector to
@@ -69,7 +75,3 @@ setMethod("[[", c("DatasetCatalog", "ANY"), function (x, i, ...) {
 ##' @seealso \code{\link{Subvariables}} \code{\link{Categories}} \code{\link[base]{names}} \code{vignette("variables", package="crunch")}
 ##' @name describe-catalog
 NULL
-
-##' @rdname describe-catalog
-##' @export
-setMethod("names", "DatasetCatalog", function (x) getIndexSlot(x, "name"))
