@@ -1,8 +1,6 @@
 init.CrunchDataset <- function (.Object, ...) {
     .Object <- callNextMethod(.Object, ...)
     .Object@variables <- getDatasetVariables(.Object)
-    ## So they test as identical, force order
-    .Object@variables@index <- .Object@variables@index[order(names(.Object@variables@index))]
     return(.Object)
 }
 setMethod("initialize", "CrunchDataset", init.CrunchDataset)
@@ -33,15 +31,6 @@ getNrow <- function (dataset, filtered=TRUE) {
 ##' @export
 is.dataset <- function (x) inherits(x, "CrunchDataset")
 
-setDatasetName <- function (x, value) {
-    out <- setTupleSlot(x, "name", value)
-    updateDatasetList() ## could just modify rather than refresh
-    invisible(out)
-}
-setDatasetDescription <- function (x, value) {
-    setTupleSlot(x, "description", value)
-}
-
 ##' Name, alias, and description for Crunch objects
 ##'
 ##' @param x a Dataset or Variable.
@@ -52,7 +41,7 @@ setDatasetDescription <- function (x, value) {
 ##' @return Getters return the character object in the specified slot; setters
 ##' return \code{x} duly modified.
 ##' @name describe
-##' @aliases describe name name<- description description<- alias<-
+##' @aliases describe name name<- description description<- alias<- startDate startDate<- endDate endDate<-
 ##' @seealso \code{\link{Categories}} \code{\link{describe-catalog}}
 NULL
 
@@ -61,20 +50,54 @@ NULL
 setMethod("name", "CrunchDataset", function (x) tuple(x)$name)
 ##' @rdname describe
 ##' @export
-setMethod("name<-", "CrunchDataset", setDatasetName)
+setMethod("name<-", c("CrunchDataset", "character"), function (x, value) {
+    out <- setTupleSlot(x, "name", value)
+    updateDatasetList() ## could just modify rather than refresh
+    invisible(out)
+})
 ##' @rdname describe
 ##' @export
 setMethod("description", "CrunchDataset", function (x) tuple(x)$description)
 ##' @rdname describe
 ##' @export
-setMethod("description<-", "CrunchDataset", setDatasetDescription)
+setMethod("description<-", "CrunchDataset", function (x, value) {
+    setTupleSlot(x, "description", value)
+})
+##' @rdname describe
+##' @export
+setMethod("startDate", "CrunchDataset",
+    function (x) trimISODate(tuple(x)$start_date))
+##' @rdname describe
+##' @export
+setMethod("startDate<-", "CrunchDataset", function (x, value) {
+    setTupleSlot(x, "start_date", value)
+})
+##' @rdname describe
+##' @export
+setMethod("endDate", "CrunchDataset",
+    function (x) trimISODate(tuple(x)$end_date))
+##' @rdname describe
+##' @export
+setMethod("endDate<-", "CrunchDataset", function (x, value) {
+    setTupleSlot(x, "end_date", value)
+})
 ##' @rdname describe
 ##' @export
 setMethod("id", "CrunchDataset", function (x) tuple(x)$id)
 
-as.dataset <- function (x, useAlias=default.useAlias(), tuple=DatasetTuple()) {
+trimISODate <- function (x) {
+    ## Drop time from datestring if it's only a date
+    if (is.character(x) &&
+        nchar(x) > 10 &&
+        substr(x, 11, nchar(x)) == "T00:00:00+00:00") {
+
+        x <- substr(x, 1, 10)
+    }
+    return(x)
+}
+
+as.dataset <- function (x, tuple=DatasetTuple()) {
     out <- CrunchDataset(x)
-    out@useAlias <- useAlias
     tuple(out) <- tuple
     return(out)
 }
@@ -92,9 +115,19 @@ NULL
 ##' @rdname dim-dataset
 ##' @export
 setMethod("dim", "CrunchDataset",
-    function (x) c(getNrow(x), length(variables(x))))
+    function (x) c(getNrow(x), ncol(x)))
 
-namekey <- function (dataset) ifelse(dataset@useAlias, "alias", "name")
+##' @rdname dim-dataset
+##' @export
+setMethod("ncol", "CrunchDataset", function (x) length(variables(x)))
+
+namekey <- function (x) {
+    if (is.variable(x)) {
+        return(match.arg(getOption("crunch.namekey.array"), c("alias", "name")))
+    } else {
+        return(match.arg(getOption("crunch.namekey.dataset"), c("alias", "name")))
+    }
+}
 
 ##' @rdname describe-catalog
 ##' @export
@@ -155,7 +188,7 @@ NULL
 ##' @export
 setMethod("refresh", "CrunchDataset", function (x) {
     tup <- refresh(tuple(x))
-    out <- as.dataset(crGET(self(x)), useAlias=x@useAlias, tuple=tup)
+    out <- as.dataset(crGET(self(x)), tuple=tup)
     duplicates(allVariables(out)) <- duplicates(allVariables(x))
     activeFilter(out) <- activeFilter(x)
     return(out)
@@ -203,9 +236,7 @@ joins <- function (x) ShojiCatalog(crGET(shojiURL(x, "catalogs", "joins")))
 setDatasetVariables <- function (x, value) {
     v <- urls(value)
     x@variables[v] <- value
-    if (!identical(ordering(x@variables), ordering(value))) {
-        ordering(x@variables) <- ordering(value)
-    }
+    ordering(x@variables) <- ordering(value)
     return(x)
 }
 
