@@ -26,8 +26,9 @@ setMethod("as.vector", "CrunchExpr", function (x, mode) {
     if (length(x@filter)) {
         payload[["filter"]] <- x@filter
     }
-    # cat(toJSON(payload))
-    out <- crPOST(paste0(x@dataset_url, "table/"), body=toJSON(payload))
+    out <- paginatedGET(paste0(x@dataset_url, "table/"),
+        query=list(query=toJSON(payload)),
+        limit=10000000000) ## Because server doesn't accept pagination yet
     ## pass in the variable metadata to the column parser
     variable <- VariableEntity(structure(list(body=out$metadata$out),
         class="shoji"))
@@ -151,6 +152,7 @@ setMethod("!", c("CrunchExpr"),
             dataset_url=datasetReference(x))
     })
 
+##' @importFrom utils head tail
 .seqCrunch <- function (x, table) {
     ## Given x %in% table, if table is numeric, see if we can/should collapse
     ## it into a range query rather than sending lots of distinct values
@@ -245,69 +247,19 @@ rollup <- function (x, resolution=rollupResolution(x)) {
 
 rollupResolution <- function (x) {
     if (is.Datetime(x)) {
-        return(entity(x)@body$view$rollup_resolution)
+        return(tuple(x)$rollup_resolution)
     } else {
         return(NULL)
     }
 }
 
-.operators <- c("+", "-", "*", "/", "<", ">", ">=", "<=", "==", "!=", "&", "|", "%in%")
-.funcs.z2r <- list(
-        and="&",
-        or="|",
-        is_missing="is.na",
-        `in`="%in%"
-    )
-
-formatExpression <- function (expr) {
-    if ("function" %in% names(expr)) {
-        func <- expr[["function"]]
-        func <- .funcs.z2r[[func]] %||% func ## Translate func name, if needed
-        args <- vapply(expr[["args"]], formatExpression, character(1),
-            USE.NAMES=FALSE)
-        if (func == "not") {
-            return(paste0("!", args[1]))
-        } else if (func %in% .operators) {
-            return(paste(args[1], func, args[2]))
-        } else {
-            return(paste0(func, "(", paste(args, collapse=", "), ")"))
-        }
-    } else if ("variable" %in% names(expr)) {
-        ## GET URL, get alias from that
-        return(crGET(expr[["variable"]])$body$alias)
-    } else if (length(intersect(c("column", "value"), names(expr)))) {
-        val <- expr$column %||% expr$value
-        if ("type" %in% names(expr) &&
-            "function" %in% names(expr$type) &&
-            expr$type[["function"]] == "typeof") {
-
-            ## GET variable, see if categorical
-            v <- crGET(expr$type$args[[1]]$variable)
-            if (v$body$type == "categorical") {
-                val <- i2n(val, categories(VariableEntity(v)))
-            }
-        }
-
-        ## Else, iterate over, replace {?:-1} with NA
-        return(capture.output(dput(val)))
-    } else {
-        ## Dunno what this is
-        return("[Complex expression]")
+##' @rdname variable-extract
+##' @export
+setMethod("[", c("CrunchExpr", "CrunchLogicalExpr"), function (x, i, ...) {
+    f <- activeFilter(x)
+    if (length(zcl(f))) {
+        i <- f & i
     }
-}
-
-##' @rdname show-crunch
-##' @export
-setMethod("show", "CrunchExpr", function (object) {
-    cat("Crunch expression: ", formatExpression(object@expression), "\n",
-        sep="")
-    invisible(object)
-})
-
-##' @rdname show-crunch
-##' @export
-setMethod("show", "CrunchLogicalExpr", function (object) {
-    cat("Crunch logical expression: ", formatExpression(object@expression), "\n",
-        sep="")
-    invisible(object)
+    activeFilter(x) <- i
+    return(x)
 })
