@@ -18,10 +18,6 @@ setMethod("filters", "CrunchDataset", function (x) {
 ##' @export
 setMethod("filters<-", "CrunchDataset", function (x, value) x)
 
-##' @rdname describe-catalog
-##' @export
-setMethod("names", "FilterCatalog", function (x) getIndexSlot(x, "name"))
-
 ##' @rdname describe
 ##' @export
 setMethod("name", "CrunchFilter", function (x) x@body$name)
@@ -71,9 +67,12 @@ setMethod("[[", c("FilterCatalog", "numeric"), function (x, i, ...) {
 ##' @export
 setMethod("[[<-", c("FilterCatalog", "character", "missing", "CrunchLogicalExpr"),
     function (x, i, j, value) {
+        stopifnot(length(i) == 1)
         if (i %in% names(x)) {
-            ## TODO: update filter with new expression
-            halt("Cannot (yet) modify filter")
+            crPATCH(urls(x)[match(i, names(x))],
+                body=toJSON(list(expression=zcl(value))))
+            ## Editing expression doesn't require invalidating the catalog
+            return(x)
         } else {
             ## Creating a new filter
             u <- crPOST(self(x), body=toJSON(list(name=i,
@@ -82,6 +81,21 @@ setMethod("[[<-", c("FilterCatalog", "character", "missing", "CrunchLogicalExpr"
         }
     })
 
+##' @rdname catalog-extract
+##' @export
+setMethod("[[<-", c("FilterCatalog", "numeric", "missing", "CrunchLogicalExpr"),
+    function (x, i, j, value) {
+        stopifnot(length(i) == 1)
+        if (i %in% seq_along(urls(x))) {
+            crPATCH(urls(x)[i],
+                body=toJSON(list(expression=zcl(value))))
+            ## Editing expression doesn't require invalidating the catalog
+            return(x)
+        } else {
+            halt("Subscript out of bounds: ", i)
+        }
+    })
+
 ##' @rdname catalog-extract
 ##' @export
 setMethod("[[<-", c("FilterCatalog", "character", "missing", "CrunchFilter"),
@@ -160,6 +174,17 @@ setMethod("activeFilter", "Subvariables", .getActiveFilter)
 setMethod("activeFilter<-", "Subvariables", .setActiveFilter)
 
 setMethod("activeFilter", "CrunchExpr", .getActiveFilter)
+setMethod("activeFilter<-", "CrunchExpr", function (x, value) {
+    ## CrunchExpr @filter can't be CrunchLogicalExpr bc of cyclical deps
+    ## so it's the @expression of that (list)
+    if (is.null(value)) {
+        value <- list()
+    } else if (inherits(value, "CrunchLogicalExpr")) {
+        value <- value@expression
+    }
+    x@filter <- value
+    return(x)
+})
 
 
 ##' View and set exclusion filters
@@ -232,3 +257,15 @@ idsToURLs <- function (expr, base_url) {
     dropCache(self(x))
     return(x)
 }
+
+setMethod("expr", "CrunchFilter",
+    function (x) {
+        ## TODO: remove this when server sends URLs instead of ids
+        e <- idsToURLs(x@body$expression,
+            absoluteURL("../../variables/", self(x)))
+        if (length(e)) {
+            return(CrunchLogicalExpr(expression=e))
+        } else {
+            return(NULL)
+        }
+    })
