@@ -7,7 +7,11 @@ setMethod("initialize", "ShojiCatalog", init.ShojiCatalog)
 
 is.shojiCatalog <- function (x) inherits(x, "ShojiCatalog")
 
-setIndexSlot <- function (x, i, value) {
+getIndexSlot <- function (x, i, what=character(1)) {
+    vapply(index(x), function (a) a[[i]], what, USE.NAMES=FALSE)
+}
+
+setIndexSlot <- function (x, i, value, unique=FALSE) {
     if (length(value) == 1) value <- rep(value, length(x))
     stopifnot(length(x) == length(value))
 
@@ -16,6 +20,15 @@ setIndexSlot <- function (x, i, value) {
         a[[i]] <- v
         return(a)
     }, a=index(x), v=value, SIMPLIFY=FALSE)
+    if (unique) {
+        ## Check to see if any of the value is duplicated after updating
+        newvals <- getIndexSlot(x, i) ## Assumes "character". Revisit if need unique for non-char
+        dups <- duplicated(newvals)
+        if (any(dups)) {
+            halt("Duplicate values not permitted: ",
+                serialPaste(unique(newvals[dups])))
+        }
+    }
     to.update <- dirtyElements(old, index(x))
     if (any(to.update)) {
         ## Make sure certain fields are [] in the JSON
@@ -35,10 +48,6 @@ dirtyElements <- function (x, y) {
     !mapply(identical, x, y, USE.NAMES=FALSE, SIMPLIFY=TRUE)
 }
 
-getIndexSlot <- function (x, i, what=character(1)) {
-    vapply(index(x), function (a) a[[i]], what, USE.NAMES=FALSE)
-}
-
 ##' @rdname catalog-extract
 ##' @export
 setMethod("[", c("ShojiCatalog", "character"), function (x, i, ...) {
@@ -53,7 +62,7 @@ setMethod("[", c("ShojiCatalog", "character"), function (x, i, ...) {
 setMethod("[", c("ShojiCatalog", "numeric"), function (x, i, ...) {
     bad <- abs(as.integer(i)) > length(x)
     if (any(bad)) {
-        halt("Subscript out of bounds: ", i[bad])
+        halt("Subscript out of bounds: ", capture.output(dput(i[bad])))
     }
     callNextMethod(x, i, value)
 })
@@ -78,12 +87,47 @@ setMethod("[", c("ShojiCatalog", "ANY"), function (x, i, ...) {
 setMethod("[[", c("ShojiCatalog", "ANY"), function (x, i, ...) {
     index(x)[[i]]
 })
+
+##' @rdname catalog-extract
+##' @export
+setMethod("[[", c("ShojiCatalog", "character"), function (x, i, ...) {
+    stopifnot(length(i) == 1L)
+    w <- whichNameOrURL(x, i)
+    if (is.na(w)) {
+        return(NULL)
+    }
+    index(x)[[w]]
+})
+
+##' @rdname catalog-extract
+##' @export
+setMethod("$", "ShojiCatalog", function (x, name) x[[name]])
+
 ##' Length of Catalog
 ##' @param x a Catalog
 ##' @return Integer: the number of elements in the index list
 ##' @name catalog-length
 NULL
 
+whichNameOrURL <- function (x, i) {
+    ns <- names(x)
+    w <- match(i, ns)
+    if (any(is.na(w))) {
+        w <- match(i, urls(x))
+    } else {
+        ## Warn if duplicated
+        dups <- i %in% ns[duplicated(ns)]
+        if (any(dups)) {
+            bads <- i[dups]
+            msg <- ifelse(length(bads) > 1,
+                " do not uniquely identify elements. Returning the first matches",
+                " does not uniquely identify elements. Returning the first match")
+            warning(i, msg, call.=FALSE)
+        }
+    }
+    return(w)
+}
+
 ##' @rdname catalog-length
 ##' @export
 setMethod("length", "ShojiCatalog", function (x) length(index(x)))
@@ -125,6 +169,15 @@ setMethod("index<-", "ShojiCatalog", function (x, value) {
 ##' @export
 setMethod("urls", "ShojiCatalog", function (x) names(index(x)))
 
+##' @rdname describe-catalog
+##' @export
+setMethod("names", "ShojiCatalog", function (x) getIndexSlot(x, "name"))
+##' @export
+##' @rdname describe-catalog
+setMethod("names<-", "ShojiCatalog", function (x, value) {
+    setIndexSlot(x, "name", value, unique=TRUE)
+})
+
 ##' @export
 as.list.ShojiCatalog <- function (x, ...) lapply(names(index(x)), function (i) x[[i]])
 
