@@ -65,6 +65,10 @@ getNameAndType <- function (x) {
 ##' @importFrom utils capture.output
 showCrunchVariable <- function (x) {
     out <- showCrunchVariableTitle(x)
+    if (!is.null(activeFilter(x))) {
+        out <- c(out,
+            paste("Filtered by", formatExpression(activeFilter(x))))
+    }
     try(out <- c(out, "", capture.output(print(summary(x)))))
     invisible(out)
 }
@@ -78,7 +82,13 @@ showCrunchDataset <- function (x) {
 
     out <- c(out,
             "",
-            paste("Contains", nrow(x), "rows of", ncol(x), "variables:"),
+            paste("Contains", nrow(x), "rows of", ncol(x), "variables:"))
+    if (!is.null(activeFilter(x))) {
+        out <- c(out,
+            paste("Filtered by", formatExpression(activeFilter(x))))
+    }
+    out <- c(out,
+            "",
             describeDatasetVariables(x))
     return(out)
 }
@@ -141,6 +151,68 @@ formatVersionCatalog <- function (x, from=Sys.time()) {
     return(data.frame(Name=names(x), Timestamp=ts, stringsAsFactors=FALSE))
 }
 
+.operators <- c("+", "-", "*", "/", "<", ">", ">=", "<=", "==", "!=", "&", "|", "%in%")
+.funcs.z2r <- list(
+        and="&",
+        or="|",
+        is_missing="is.na",
+        `in`="%in%"
+    )
+
+formatExpression <- function (expr) {
+    if (inherits(expr, "CrunchExpr")) {
+        return(formatExpression(expr@expression))
+    } else if ("function" %in% names(expr)) {
+        func <- expr[["function"]]
+        func <- .funcs.z2r[[func]] %||% func ## Translate func name, if needed
+        args <- vapply(expr[["args"]], formatExpression, character(1),
+            USE.NAMES=FALSE)
+        if (func == "not") {
+            return(paste0("!", args[1]))
+        } else if (func %in% .operators) {
+            return(paste(args[1], func, args[2]))
+        } else {
+            return(paste0(func, "(", paste(args, collapse=", "), ")"))
+        }
+    } else if ("variable" %in% names(expr)) {
+        ## GET URL, get alias from that
+        return(crGET(expr[["variable"]])$body$alias)
+    } else if (length(intersect(c("column", "value"), names(expr)))) {
+        val <- expr$column %||% expr$value
+        if ("type" %in% names(expr) &&
+            "function" %in% names(expr$type) &&
+            expr$type[["function"]] == "typeof") {
+
+            ## GET variable, see if categorical
+            v <- crGET(expr$type$args[[1]]$variable)
+            if (v$body$type == "categorical") {
+                val <- i2n(val, categories(VariableEntity(v)))
+            }
+        }
+
+        ## Else, iterate over, replace {?:-1} with NA
+        return(capture.output(dput(val)))
+    } else {
+        ## Dunno what this is
+        return("[Complex expression]")
+    }
+}
+
+##' @rdname show-crunch
+##' @export
+setMethod("show", "CrunchExpr", function (object) {
+    cat("Crunch expression: ", formatExpression(object), "\n",
+        sep="")
+    invisible(object)
+})
+
+##' @rdname show-crunch
+##' @export
+setMethod("show", "CrunchLogicalExpr", function (object) {
+    cat("Crunch logical expression: ", formatExpression(object), "\n",
+        sep="")
+    invisible(object)
+})
 
 # More boilerplate
 
@@ -165,11 +237,8 @@ setMethod("getShowContent", "ShojiObject",
     function (x) capture.output(print(x@body)))
 setMethod("getShowContent", "CrunchFilter",
     function (x) {
-        ## TODO: remove this when server sends URLs instead of ids
-        e <- idsToURLs(x@body$expression,
-            absoluteURL("../../variables/", self(x)))
         return(c(paste("Crunch filter", dQuote(name(x))),
-        paste("Expression:", formatExpression(e))))
+            paste("Expression:", formatExpression(expr(x)))))
     })
 
 ##' @rdname show-crunch
