@@ -24,34 +24,34 @@ getSummary <- function (x) {
 ##' @param deparse.level see \code{\link[base]{table}}
 ##' @return a table object
 ##' @seealso \code{\link[base]{table}}
-##' @export 
+##' @export
 table <- function (..., exclude, useNA=c("no", "ifany", "always"), dnn, deparse.level) {
     m <- match.call()
-    
+
     dots <- list(...)
-    are.vars <- vapply(dots, 
-        function (x) is.variable(x) || inherits(x, "CrunchExpr"), 
+    are.vars <- vapply(dots,
+        function (x) is.variable(x) || inherits(x, "CrunchExpr"),
         logical(1))
     if (length(are.vars) && all(are.vars)) {
         query <- list(dimensions=varsToCubeDimensions(dots),
             measures=list(count=zfunc("cube_count")))
         ## Check for filters
-        filters <- vapply(dots, 
-            function (x) toJSON(filterSyntax(activeFilter(x))), 
+        filters <- vapply(dots,
+            function (x) toJSON(zcl(activeFilter(x))),
             character(1))
         if (!all(filters == filters[1])) {
             halt("Filter expressions in variables must be identical")
         }
         query <- list(
             query=toJSON(query),
-            filter_syntax=filters[1]
+            filter=filters[1]
         )
         cube_url <- absoluteURL("./cube/", datasetReference(dots[[1]]))
         cube <- CrunchCube(crGET(cube_url, query=query),
             useNA=match.arg(useNA))
         return(as.table(as.array(cube)))
     } else if (any(are.vars)) {
-        halt("Cannot currently tabulate Crunch variables with ", 
+        halt("Cannot currently tabulate Crunch variables with ",
             "non-Crunch vectors")
     } else {
         m[[1]] <- quote(base::table)
@@ -60,11 +60,11 @@ table <- function (..., exclude, useNA=c("no", "ifany", "always"), dnn, deparse.
 }
 
 #setGeneric("table", signature="...")
-# ## @export 
+# ## @export
 #setMethod("table", "CategoricalVariable", CategoricalVariable.table)
 
 ##' Summary methods for Crunch Variables
-##' 
+##'
 ##' @param object A Variable
 ##' @param ... additional arguments, ignored (they're in the summary.default)
 ##' signature
@@ -101,4 +101,3 @@ summary.NumericVariable <- function (object, ...) {
     attr(out, "varname") <- getNameAndType(object)
     return(out)
 }
-
