@@ -13,15 +13,12 @@
 .updatePayload <- function (variable, value) {
     ## Construct the "variables" key of a ZCL update payload
     if (is.Array(variable)) {
-        # subvars <- index(subvariables(variable))
-        # subids <- unlist(lapply(subvars, function (x) x$id))
         out <- sapply(urls(subvariables(variable)), function (x) {
             zcl(typeof(value,
                 structure(zfunc("typeof",
                 structure(list(variable=x), class="zcl")),
                     class="zcl")))
             }, simplify=FALSE)
-        # names(out) <- subids
     } else {
         out <- structure(list(zcl(typeof(value, variable))),
             .Names=self(variable))
@@ -164,22 +161,28 @@ setMethod("[<-", c("CrunchVariable", "CrunchExpr", "missing", "CrunchExpr"),
 
 ##' @rdname variable-update
 ##' @export
-setMethod("[<-", c("CategoricalVariable", "ANY", "missing", "numeric"), .categorical.update[["numeric"]])
+setMethod("[<-", c("CategoricalVariable", "ANY", "missing", "numeric"),
+    .categorical.update[["numeric"]])
 ##' @rdname variable-update
 ##' @export
-setMethod("[<-", c("CategoricalVariable", "ANY", "missing", "character"), .categorical.update[["character"]])
+setMethod("[<-", c("CategoricalVariable", "ANY", "missing", "character"),
+    .categorical.update[["character"]])
 ##' @rdname variable-update
 ##' @export
-setMethod("[<-", c("CategoricalVariable", "ANY", "missing", "factor"), .categorical.update[["factor"]])
+setMethod("[<-", c("CategoricalVariable", "ANY", "missing", "factor"),
+    .categorical.update[["factor"]])
 ##' @rdname variable-update
 ##' @export
-setMethod("[<-", c("CategoricalArrayVariable", "ANY", "missing", "numeric"), .categorical.update[["numeric"]])
+setMethod("[<-", c("CategoricalArrayVariable", "ANY", "missing", "numeric"),
+    .categorical.update[["numeric"]])
 ##' @rdname variable-update
 ##' @export
-setMethod("[<-", c("CategoricalArrayVariable", "ANY", "missing", "character"), .categorical.update[["character"]])
+setMethod("[<-", c("CategoricalArrayVariable", "ANY", "missing", "character"),
+    .categorical.update[["character"]])
 ##' @rdname variable-update
 ##' @export
-setMethod("[<-", c("CategoricalArrayVariable", "ANY", "missing", "factor"), .categorical.update[["factor"]])
+setMethod("[<-", c("CategoricalArrayVariable", "ANY", "missing", "factor"),
+    .categorical.update[["factor"]])
 
 ##' @rdname variable-update
 ##' @export
