@@ -32,6 +32,14 @@ test_that("toVariable parses R Date class", {
             resolution="D"))
 })
 
+test_that("toVariable handles POSIX datetimes", {
+    skip("Investigate precision")
+    numtime <- 1454238117.123 ## Note that it's off by 1ms below...
+    expect_equivalent(toVariable(as.POSIXct(numtime, origin="1970-01-01", tz="UTC")),
+        list(values="2016-01-31T03:01:57.122", type="datetime",
+            resolution="ms"))
+})
+
 test_that("POSTNewVariable rejects invalid categories", {
     expect_error(POSTNewVariable("",
         list(type="categorical", name="bad ids",
