@@ -15,7 +15,7 @@ test_that("askForPermission says no if not interactive", {
     expect_false(askForPermission())
 })
 
-with(fake.HTTP, {
+with_mock_HTTP({
     ds <- loadDataset("test ds")
     test_that("Cannot append dataset to itself", {
         expect_error(appendDataset(ds, ds),
@@ -48,7 +48,6 @@ if (run.integration.tests) {
                 status <- pollBatchStatus(out, batches(part1),
                     until="imported")
                 test_that("batch status can be polled while we wait", {
-                    expect_that(status, is_not_an_error())
                     expect_identical(status, "imported")
                 })
             })
