@@ -51,12 +51,12 @@ if (run.integration.tests) {
             ordering(f1) <- VariableOrder(VariableGroup("Even", f1[c(2,4,6)]),
                 VariableGroup("Odd", f1[c(1,3,5)]))
 
-            # 4. Derive variable
-            f1$v7 <- f1$v3 - 6
-
             # 5. Add non-derived variable
             f1$v8 <- rep(1:5, 4)
 
+            # 4. Derive variable
+            f1$v7 <- f1$v3 - 6
+
             ## Assert those things
             test_that("The edits are made to the fork", {
                 expect_identical(names(na.omit(categories(f1$v4))),
@@ -68,7 +68,7 @@ if (run.integration.tests) {
                 expect_identical(as.vector(f1$v7), df$v3 - 6)
                 expect_equivalent(as.vector(f1$v8), rep(1:5, 4))
                 expect_identical(aliases(variables(f1)),
-                    paste0("v", c(2,4,6,1,3,5,7,8)))
+                    paste0("v", c(2,4,6,1,3,5,8,7)))
             })
 
             test_that("The upstream dataset is unaffected by edits to the fork", {
@@ -78,23 +78,23 @@ if (run.integration.tests) {
             ## So that f1 gets cleaned up even if merge fails
             with(test.dataset(f1, "f1"), {
                 ## Now merge f1 back to ds
+                ds <- mergeFork(ds, f1)
                 test_that("The edits made to the fork are now upstream", {
-                    skip(paste("(409) Conflict: The given workflow could not be",
-                        "successfully run on this dataset. The dataset has been",
-                        "restored to the state before the attempted merge. Include",
-                        "a body.autorollback=false member in the future to allow",
-                        "analysis and repair instead."))
-                    ds <- mergeFork(ds, f1)
                     expect_identical(names(na.omit(categories(ds$v4))),
                         c("d", "e"))
                     expect_identical(name(ds$v2), "Variable Two")
                     expect_identical(description(ds$v3),
                         "The third variable in the dataset")
-                    expect_identical(description(ds), "A dataset for testing")
                     expect_identical(as.vector(ds$v7), df$v3 - 6)
                     expect_equivalent(as.vector(ds$v8), rep(1:5, 4))
                     expect_identical(aliases(variables(ds)),
-                        paste0("v", c(2,4,6,1,3,5,7,8)))
+                        paste0("v", c(2,4,6,1,3,5,8,7)))
+                    ## Extra checks for v7 and v8
+                    expect_true("v7" %in% aliases(allVariables(ds)))
+                    expect_true("v8" %in% aliases(allVariables(ds)))
+                })
+                test_that("Certain changes don't merge", {
+                    expect_identical(description(ds), "")
                 })
             })
         })
