@@ -1,6 +1,8 @@
 context("Retrieving dataset list and single datasets")
 
-with(fake.HTTP, {
+with_mock_HTTP({
+    cr <- session()
+
     dataset.catalog.url <- "/api/datasets.json"
     datcat <- DatasetCatalog(crGET(dataset.catalog.url))
     index(datcat)[[which(names(datcat) == "an archived dataset")]]$archived <- TRUE
@@ -21,6 +23,22 @@ with(fake.HTTP, {
         expect_true(is.dataset(ds))
         expect_identical(name(ds), "test ds")
         expect_error(loadDataset(666), "subscript out of bounds")
+        expect_error(loadDataset("not a dataset"),
+            paste(dQuote("not a dataset"), "not found"))
+    })
+
+    test_that("loadDataset loads with DatasetTuple", {
+        ds <- loadDataset(cr$datasets[["test ds"]])
+        expect_true(is.dataset(ds))
+        expect_identical(name(ds), "test ds")
+        expect_true(is.dataset(loadDataset(cr$datasets$`test ds`)))
+    })
+
+    test_that("deleteDataset error handling", {
+        expect_error(deleteDataset("this is totally not a dataset",
+            paste(dQuote("this is totally not a dataset"), "not found")))
+        expect_error(deleteDataset(9999),
+            "subscript out of bounds")
     })
 })
 
@@ -53,24 +71,13 @@ if (run.integration.tests) {
 
             test_that("A dataset object can be retrieved, if it exists", {
                 expect_true(is.dataset(loadDataset(dsname)))
-                expect_error(loadDataset("this is totally not a dataset"),
-                    paste(dQuote("this is totally not a dataset"), "not found"))
                 dsnum <- which(listDatasets() %in% dsname)
                 expect_true(is.numeric(dsnum))
                 expect_true(is.dataset(loadDataset(dsnum)))
-                expect_error(loadDataset(9999))
-            })
-            test_that("loadDataset respects useAlias", {
-                expect_equal(loadDataset(dsname)@useAlias,
-                    default.useAlias())
-                expect_false(loadDataset(dsname, useAlias=FALSE)@useAlias)
             })
 
             test_that("deleteDataset by name", {
-                expect_error(deleteDataset("this is totally not a dataset",
-                    paste(dQuote("this is totally not a dataset"), "not found")))
                 out <- try(deleteDataset(dsname))
-                expect_that(out, is_not_an_error())
                 expect_false(dsname %in% listDatasets())
             })
         })
@@ -80,11 +87,7 @@ if (run.integration.tests) {
             dsnum <- which(listDatasets() %in% dsname)
             test_that("deleteDataset by index", {
                 expect_true(dsname %in% listDatasets())
-
-                expect_error(deleteDataset(dsnum + 9999),
-                    "subscript out of bounds")
-                out <- try(deleteDataset(dsnum))
-                expect_that(out, is_not_an_error())
+                out <- deleteDataset(dsnum)
                 expect_false(dsname %in% listDatasets())
             })
         })
@@ -93,8 +96,7 @@ if (run.integration.tests) {
             dsname <- name(ds)
             test_that("deleteDataset on Dataset object", {
                 expect_true(dsname %in% listDatasets())
-                out <- try(deleteDataset(ds))
-                expect_that(out, is_not_an_error())
+                out <- deleteDataset(ds)
                 expect_false(dsname %in% listDatasets())
             })
         })
